==========
alternator
==========

Alternator provides tools to ease the creation of `asynchronous generators`__.

__ https://www.python.org/dev/peps/pep-0492/


Synchronous generators are pretty easy to create and manipulate in Python.  In
Python 3.5 asynchronous generators are possible.  Consuming them with ``async
for`` is pretty nice, but creating them is a fairly manual process.

Maybe a future version of Python will correct this imbalance.

Or maybe we can fix it with TOOLS!
